<?php
/**
 * FaceBlog Theme Customizer.
 *
 * @package Mystery Themes
 * @subpackage FaceBlog
 * @since 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function faceblog_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
        'selector' => '.site-title a',
        'render_callback' => 'faceblog_customize_partial_blogname',
    ) );

    $wp_customize->selective_refresh->add_partial( 'blogdescription', array(
        'selector' => '.site-description',
        'render_callback' => 'faceblog_customize_partial_blogdescription',
    ) );
}
add_action( 'customize_register', 'faceblog_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @since FaceBlog 1.0.9
 * @see uniform_customize_register()
 *
 * @return void
 */
function faceblog_customize_partial_blogname() {
    bloginfo( 'name' );
}

/**
 * Render the site title for the selective refresh partial.
 *
 * @since FaceBlog 1.0.9
 * @see uniform_customize_register()
 *
 * @return void
 */
function faceblog_customize_partial_blogdescription() {
    bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function faceblog_customize_preview_js() {
	wp_enqueue_script( 'faceblog_customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'faceblog_customize_preview_js' );

/**
 * Load Customizer panels
 */
require get_template_directory() . '/inc/customizer/general-panel.php'; //general settings panel
require get_template_directory() . '/inc/customizer/header-panel.php'; //header settings panel
require get_template_directory() . '/inc/customizer/frontpage-panel.php'; //frontpage settings panel
require get_template_directory() . '/inc/customizer/design-panel.php'; //design settings panel
require get_template_directory() . '/inc/customizer/footer-panel.php'; //footer settings panel

/**
 * Load customizer required files
 */
require get_template_directory() . '/inc/customizer/faceblog-customize-controls.php'; //customizer custom class
require get_template_directory() . '/inc/customizer/faceblog-sanitize.php'; // sanitize file
